from PyObjCTools.TestSupport import TestCase, min_os_level


import Social


class TestSLTypes(TestCase):
    @min_os_level("10.8")
    def testConstants(self):
        self.assertIsInstance(Social.SLServiceTypeTwitter, str)
        self.assertIsInstance(Social.SLServiceTypeFacebook, str)
        self.assertIsInstance(Social.SLServiceTypeSinaWeibo, str)

    @min_os_level("10.9")
    def testConstants10_9(self):
        self.assertIsInstance(Social.SLServiceTypeTencentWeibo, str)
        self.assertIsInstance(Social.SLServiceTypeLinkedIn, str)



import Social
from PyObjCTools.TestSupport import TestCase, min_os_level

SLRequestHandler = b"v@@@"


class TestSLRequest(TestCase):
    @min_os_level("10.8")
    def testConstants(self):
        self.assertEqual(Social.SLRequestMethodGET, 0)
        self.assertEqual(Social.SLRequestMethodPOST, 1)
        self.assertEqual(Social.SLRequestMethodDELETE, 2)
        self.assertEqual(Social.SLRequestMethodPUT, 3)

    @min_os_level("10.8")
    def testMethods(self):
        self.assertArgIsBlock(
            Social.SLRequest.performRequestWithHandler_, 0, SLRequestHandler
        )



# This file is generated by objective.metadata
#
# Last update: Sat Jun 27 18:39:10 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$SLServiceTypeFacebook$SLServiceTypeLinkedIn$SLServiceTypeSinaWeibo$SLServiceTypeTencentWeibo$SLServiceTypeTwitter$"""
enums = """$SLRequestMethodDELETE@2$SLRequestMethodGET@0$SLRequestMethodPOST@1$SLRequestMethodPUT@3$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"SLComposeServiceViewController", b"isContentValid", {"retval": {"type": b"Z"}})
    r(
        b"SLRequest",
        b"performRequestWithHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                            3: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



"""
Wrappers for the "Social" framework on macOS 10.8 or later.

Note that this framework is only available for 64-bit code.
"""

from pyobjc_setup import setup

VERSION = "7.3"

setup(
    name="pyobjc-framework-Social",
    description="Wrappers for the framework Social on macOS",
    min_os_level="10.8",
    packages=["Social"],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
)
